@@ -359,7 +359,7 @@ class Microservice(core.Construct):
             protocol=protocol,
             vpc=self._vpc,
             target_type=_alb.TargetType.INSTANCE,
-            target_group_name=(app_name + id + "-tg").replace("_", "-"),
+            target_group_name=(app_name + id + ec2_traffic_port).replace("_", "-"),
             stickiness_cookie_duration=core.Duration.hours(int(stickiness_cookie_duration_in_hours)) if stickiness_cookie_duration_in_hours else None,
         )
         tg.configure_health_check(
@@ -448,7 +448,7 @@ class Microservice(core.Construct):
                 "alb_secg_cdn", 
                 app_name, 
                 environment, 
-                app_name + "_alb_secg_cdn",
+                app_name + '_' + main_component_name + "_alb_secg_cdn",
                 )
 
             # Cloudflare doc https://support.cloudflare.com/hc/en-us/articles/360037983412-Configuring-an-Amazon-Web-Services-static-site-to-use-Cloudflare
