@@ -238,6 +238,14 @@ class ServiceUserForIAC(core.Construct):
                         "arn:aws:cloudfront:eu-west-1:*:*:*:*" + app_name + "*",
                     ],
                 ),
+                _iam.PolicyStatement(
+                    actions=[
+                        "kendra:*",
+                    ],
+                    resources=[
+                        "arn:aws:kendra:eu-west-1:*:*" + app_name + "*",
+                    ],
+                ),
                 # Filter by TAG
                 _iam.PolicyStatement(
                     actions=[
@@ -253,7 +261,8 @@ class ServiceUserForIAC(core.Construct):
                         "logs:*",
                         "iam:*",
                         "elasticfilesystem:*",
-                        "cloudfront:*"
+                        "cloudfront:*",
+                        "kendra:*",
                     ],
                     resources=["*"],
                     conditions={
@@ -276,7 +285,8 @@ class ServiceUserForIAC(core.Construct):
                         "logs:*",
                         "iam:*",
                         "elasticfilesystem:*",
-                        "cloudfront:*"
+                        "cloudfront:*",
+                        "kendra:*",
                     ],
                     resources=["*"],
                     conditions={
